brillo-2.0.0: Painless 2D vector graphics, animations, and simulations powered by GLFW
Safe HaskellNone
LanguageGHC2021

Brillo.Data.FileDialog

Synopsis

Documentation

data FileDialog Source #

The FileDialog represents a dialog | that can be opened by the user to select files or directories.

Constructors

FileDialog 

Fields

Instances

Instances details
Show FileDialog Source # 
Instance details

Defined in Brillo.Data.FileDialog

Eq FileDialog Source # 
Instance details

Defined in Brillo.Data.FileDialog