| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Brillo.Data.Picture
Contents
Synopsis
- data Picture
- = Blank
- | Polygon Path
- | PolygonAliased Path
- | Line Path
- | LineAliased Path
- | ThickLine Path Float
- | ThickLineAliased Path Float
- | Circle Float
- | CircleAliased Float
- | ThickCircle Float Float
- | ThickCircleAliased Float Float
- | Arc Float Float Float
- | ArcAliased Float Float Float
- | ThickArc Float Float Float Float
- | ThickArcAliased Float Float Float Float
- | Text Text
- | TextAliased Text
- | ThickText Text Float
- | ThickTextAliased Text Float
- | TrueTypeText FilePath Int Text
- | Bitmap BitmapData
- | BitmapSection Rectangle BitmapData
- | Color Color Picture
- | Translate Float Float Picture
- | Rotate Float Picture
- | Scale Float Float Picture
- | Pictures [Picture]
- type Point = (Float, Float)
- type Vector = Point
- type Path = [Point]
- lineLoop :: Path -> Picture
- lineLoopAliased :: Path -> Picture
- circleSolid :: Float -> Picture
- circleSolidAliased :: Float -> Picture
- arcSolid :: Float -> Float -> Float -> Picture
- arcSolidAliased :: Float -> Float -> Float -> Picture
- sectorWire :: Float -> Float -> Float -> Picture
- sectorWireAliased :: Float -> Float -> Float -> Picture
- rectanglePath :: Float -> Float -> Path
- rectangleWire :: Float -> Float -> Picture
- rectangleWireAliased :: Float -> Float -> Picture
- rectangleSolid :: Float -> Float -> Picture
- rectangleSolidAliased :: Float -> Float -> Picture
- rectangleUpperPath :: Float -> Float -> Path
- rectangleUpperWire :: Float -> Float -> Picture
- rectangleUpperWireAliased :: Float -> Float -> Picture
- rectangleUpperSolid :: Float -> Float -> Picture
- rectangleUpperSolidAliased :: Float -> Float -> Picture
Documentation
Constructors
Instances
| Data Picture | |
Defined in Brillo.Internals.Data.Picture Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> Picture -> c Picture # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c Picture # toConstr :: Picture -> Constr # dataTypeOf :: Picture -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c Picture) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c Picture) # gmapT :: (forall b. Data b => b -> b) -> Picture -> Picture # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> Picture -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> Picture -> r # gmapQ :: (forall d. Data d => d -> u) -> Picture -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> Picture -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> Picture -> m Picture # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> Picture -> m Picture # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> Picture -> m Picture # | |
| Monoid Picture | |
| Semigroup Picture | |
| Show Picture | |
| Eq Picture | |
Compound shapes
lineLoopAliased :: Path -> Picture Source #
A closed loop along a path, drawn without anti-aliasing.
circleSolid :: Float -> Picture Source #
A solid circle with the given radius, drawn with anti-aliasing.
circleSolidAliased :: Float -> Picture Source #
A solid circle with the given radius, drawn without anti-aliasing.
arcSolid :: Float -> Float -> Float -> Picture Source #
A solid arc, drawn counter-clockwise between two angles (in degrees) at the given radius, with anti-aliasing.
arcSolidAliased :: Float -> Float -> Float -> Picture Source #
A solid arc, drawn counter-clockwise between two angles (in degrees) at the given radius, without anti-aliasing.
sectorWire :: Float -> Float -> Float -> Picture Source #
A wireframe sector of a circle, drawn with anti-aliasing. An arc is draw counter-clockwise from the first to the second angle (in degrees) at the given radius. Lines are drawn from the origin to the ends of the arc.
sectorWireAliased :: Float -> Float -> Float -> Picture Source #
A wireframe sector of a circle, drawn without anti-aliasing. An arc is draw counter-clockwise from the first to the second angle (in degrees) at the given radius. Lines are drawn from the origin to the ends of the arc.
A path representing a rectangle centered about the origin
rectangleWire :: Float -> Float -> Picture Source #
A wireframe rectangle centered about the origin, drawn with anti-aliasing.
rectangleWireAliased :: Float -> Float -> Picture Source #
A wireframe rectangle centered about the origin, drawn without anti-aliasing.
rectangleSolid :: Float -> Float -> Picture Source #
A solid rectangle centered about the origin, drawn with anti-aliased edges.
rectangleSolidAliased :: Float -> Float -> Picture Source #
A solid rectangle centered about the origin, drawn without anti-aliasing.
rectangleUpperPath :: Float -> Float -> Path Source #
A path representing a rectangle in the y > 0 half of the x-y plane.
rectangleUpperWire :: Float -> Float -> Picture Source #
A wireframe rectangle in the y > 0 half of the x-y plane, drawn with anti-aliasing.
rectangleUpperWireAliased :: Float -> Float -> Picture Source #
A wireframe rectangle in the y > 0 half of the x-y plane, drawn without anti-aliasing.