| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Brillo.Interface.Environment
Synopsis
- getScreenSize :: IO (Int, Int)
- openFileDialog :: FileDialog -> IO (Maybe [FilePath])
- saveFileDialog :: Text -> Text -> [Text] -> Text -> IO (Maybe FilePath)
Documentation
getScreenSize :: IO (Int, Int) Source #
Get the size of the screen, in pixels.
This will be the size of the rendered brillo image when fullscreen mode is enabled.
openFileDialog :: FileDialog -> IO (Maybe [FilePath]) Source #
Open a file dialog to select files/directories.
Returns a list of paths, or Nothing if the dialog was cancelled.